# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 3.8.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DatasetsuploadlargecompleteParts(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'part_number': 'float',
        'e_tag': 'str'
    }

    attribute_map = {
        'part_number': 'PartNumber',
        'e_tag': 'ETag'
    }

    def __init__(self, part_number=None, e_tag=None):  # noqa: E501
        """DatasetsuploadlargecompleteParts - a model defined in Swagger"""  # noqa: E501
        self._part_number = None
        self._e_tag = None
        self.discriminator = None
        if part_number is not None:
            self.part_number = part_number
        if e_tag is not None:
            self.e_tag = e_tag

    @property
    def part_number(self):
        """Gets the part_number of this DatasetsuploadlargecompleteParts.  # noqa: E501


        :return: The part_number of this DatasetsuploadlargecompleteParts.  # noqa: E501
        :rtype: float
        """
        return self._part_number

    @part_number.setter
    def part_number(self, part_number):
        """Sets the part_number of this DatasetsuploadlargecompleteParts.


        :param part_number: The part_number of this DatasetsuploadlargecompleteParts.  # noqa: E501
        :type: float
        """

        self._part_number = part_number

    @property
    def e_tag(self):
        """Gets the e_tag of this DatasetsuploadlargecompleteParts.  # noqa: E501


        :return: The e_tag of this DatasetsuploadlargecompleteParts.  # noqa: E501
        :rtype: str
        """
        return self._e_tag

    @e_tag.setter
    def e_tag(self, e_tag):
        """Sets the e_tag of this DatasetsuploadlargecompleteParts.


        :param e_tag: The e_tag of this DatasetsuploadlargecompleteParts.  # noqa: E501
        :type: str
        """

        self._e_tag = e_tag

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DatasetsuploadlargecompleteParts, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DatasetsuploadlargecompleteParts):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
